Re-exports of the runtime traits and types that generated Gust code
relies on. Generated .g.rs files use gust_runtime::prelude::*; to
bring Machine, Supervisor, Envelope, RestartStrategy, and
third-party re-exports (serde, serde_json, thiserror) into scope.
Re-exports
pub use serde_json;pub use thiserror;
Structs
- Child
Handle - A handle to a child task spawned by a
SupervisorRuntime. - Envelope
- A typed message envelope for cross-machine communication.
- Supervisor
Runtime - An async runtime for supervising a group of child tasks.
Enums
- Restart
Strategy - Strategy that determines which children are restarted when one fails.
- Supervisor
Action - The action a
Supervisortakes when a child machine fails.
Traits
- Deserialize
- A data structure that can be deserialized from any data format supported by Serde.
- Machine
- The base trait for all Gust state machines.
- Serialize
- A data structure that can be serialized into any data format supported by Serde.
- Supervisor
- A trait for supervised machine groups (structured concurrency).