pub struct ChildHandle {
pub id: String,
}Expand description
A handle to a child task spawned by a SupervisorRuntime.
Contains the logical identifier of the child, which is used for
logging and passed to Supervisor::on_child_failure when the
child reports an error.
Fields
id: StringThe logical identifier of this child task.