Module prelude

Module prelude 

Re-exports of the runtime traits and types that generated Gust code relies on. Generated .g.rs files use gust_runtime::prelude::*; to bring Machine, Supervisor, Envelope, RestartStrategy, and third-party re-exports (serde, serde_json, thiserror) into scope.

Re-exports

pub use serde_json;
pub use thiserror;

Structs

ChildHandle
A handle to a child task spawned by a SupervisorRuntime.
Envelope
A typed message envelope for cross-machine communication.
SupervisorRuntime
An async runtime for supervising a group of child tasks.

Enums

RestartStrategy
Strategy that determines which children are restarted when one fails.
SupervisorAction
The action a Supervisor takes when a child machine fails.

Traits

Deserialize
A data structure that can be deserialized from any data format supported by Serde.
Machine
The base trait for all Gust state machines.
Serialize
A data structure that can be serialized into any data format supported by Serde.
Supervisor
A trait for supervised machine groups (structured concurrency).

Derive Macros

Deserialize
Serialize